@@ -1,5 +1,5 @@
 print("aaa")
 
 
-def test():
+def my_one():
     print("pip first test")
